export async function fetchRestApi(route, restApiUrl, request) {
    const pathParams = 'pathParams' in request ? request.pathParams : undefined;
    const queryParams = 'queryParams' in request ? request.queryParams : undefined;
    const headers = 'headers' in request ? request.headers : undefined;
    const body = 'body' in request ? request.body : undefined;
    const url = `${restApiUrl}${route.buildUrl(pathParams, queryParams)}`;
    const response = await fetch(url, {
        method: route.method,
        headers: headers,
        body: body ? JSON.stringify(body) : null,
    });
    if (!response.ok && response.status !== 404)
        throw `Request ${route.method} ${url} failed`;
    const text = (await response.text()).trim();
    return response.ok && response.status !== 204
        ? JSON.parse(text)
        : null;
}
//# sourceMappingURL=fetchRestApi.js.map